Re: [PATCH] Use a hashtable for objects instead of a sorted list
- From
Junio C Hamano <junkio@cox.net>
- Date
- Feb 12, 2006, 12:11 UTC
- Message-ID
- <7vaccwdbfs.fsf@assigned-by-dhcp.cox.net>
- In-Reply-To
- <87oe1dez7k.fsf@wine.dyndns.org>
Alexandre Julliard <julliard@winehq.org> writes:
Show 7 quoted lines
> Junio C Hamano <junkio@cox.net> writes: > >> Alexandle, if you have a chance, could you try Johannes' patch >> on your workload to see if it works OK for you? > > It works great for me, CPU time is down to 15 sec instead of 20 sec > with my patch.
Thanks. Now we have three independent numbers to back up that Johannes is the winner....
Grrrrrrr. Please, DO NOT USE THIS ONE YET.
At least, not with your production repository.
I am trying to nail it down but it appears at least fsck-objects using this version gives bogus results. I am first trying to see if my primary working repository is sane.
Oh, and thanks again for your initial patch, which was what started this drastic improvement.